<?php
defined( 'ABSPATH' ) || exit;

class TOCHATBE_Admin_Init {

    public function __construct() {
        add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ), 20 );
        add_action( 'admin_menu', array( $this, 'admin_menu' ) );
        add_action( 'admin_init', array( $this, 'register_plugin_settings' ), 20 );
    }

    public function admin_enqueue_scripts( $hook ) {
        if ( 'tochat-be_page_to-chat-be-whatsapp_appearence' === $hook
        || 'tochat-be_page_to-chat-be-whatsapp_settings' === $hook
        || 'tochat-be_page_to-chat-be-whatsapp_shortcode' === $hook
        || 'tochat-be_page_to-chat-be-whatsapp_gdpr' === $hook
        || 'tochat-be_page_to-chat-be-whatsapp_click-log' === $hook ) {
            wp_enqueue_style( 'wp-color-picker' );
            wp_enqueue_script( 'wp-color-picker' );

            wp_enqueue_script( 'admin-tochatbe', TOCHATBE_PLUGIN_URL . 'assets/js/admin-tochatbe-script.js', array(), TOCHATBE_PLUGIN_URL, true );
            wp_enqueue_style( 'admin-tochatbe', TOCHATBE_PLUGIN_URL . 'assets/css/admin-tochatbe-style.css', array(), TOCHATBE_PLUGIN_URL );
        }

    }

    public function admin_menu() {
        add_menu_page( 
            'TOCHAT.BE', 
            'TOCHAT.BE', 
            'manage_options', 
            'to-chat-be-whatsapp', 
            '', 
            'dashicons-format-chat' 
        );
        add_submenu_page( 
            'to-chat-be-whatsapp', 
            'Appearence', 
            'Appearence', 
            'manage_options', 
            'to-chat-be-whatsapp_appearence', 
            array( $this, 'admin_appearance_settings' ) 
        );
        add_submenu_page( 
            'to-chat-be-whatsapp', 
            'Settings', 
            'Settings', 
            'manage_options', 
            'to-chat-be-whatsapp_settings', 
            array( $this, 'admin_basic_settings' ) 
        );
        add_submenu_page( 
            'to-chat-be-whatsapp', 
            'Shortcode', 
            'Shortcode', 
            'manage_options', 
            'to-chat-be-whatsapp_shortcode', 
            array( $this, 'admin_shortcode_page' ) 
        );
        add_submenu_page( 
            'to-chat-be-whatsapp', 
            'GDPR', 
            'GDPR', 
            'manage_options', 
            'to-chat-be-whatsapp_gdpr', 
            array( $this, 'admin_gdpr_settings' ) 
        );
        add_submenu_page( 
            'to-chat-be-whatsapp', 
            'Click Log', 
            'Click Log', 
            'manage_options', 
            'to-chat-be-whatsapp_click-log', 
            array( $this, 'admin_click_log_page' ) 
        );
    }

    public function admin_appearance_settings() {
        require_once TOCHATBE_PLUGIN_PATH . 'includes/admin/views/html-appearance-settings.php';
    }

    public function admin_basic_settings() {
        require_once TOCHATBE_PLUGIN_PATH . 'includes/admin/views/html-basic-settings.php';
    }

    public function admin_gdpr_settings() {
        require_once TOCHATBE_PLUGIN_PATH . 'includes/admin/views/html-gdpr-settings.php';
    }

    public function admin_shortcode_page() {
        require_once TOCHATBE_PLUGIN_PATH . 'includes/admin/views/html-shortcode-page.php';
    }

    public function admin_click_log_page() {
        require_once TOCHATBE_PLUGIN_PATH . 'includes/admin/views/html-click-log.php';
    }

    public function register_plugin_settings() {
        register_setting( 'tochatbe-appearance-settings', 'tochatbe_appearance_settings', array( $this, 'sanitize_appearance_settings' ) );
        register_setting( 'tochatbe-basic-settings', 'tochatbe_basic_settings', array( $this, 'sanitize_basic_settings' ) );
        register_setting( 'tochatbe-gdpr-settings', 'tochatbe_gdpr_settings', array( $this, 'sanitize_gdpr_settings' ) );
    }

    public function sanitize_appearance_settings( $input ) {
        $input['background_color']  = sanitize_hex_color( $input['background_color'] );
        $input['text_color']        = sanitize_hex_color( $input['text_color'] );
        $input['about_message']     = sanitize_textarea_field( $input['about_message'] );
        $input['triiger_btn_text']  = sanitize_text_field( $input['triiger_btn_text'] );

        return $input;
    }

    public function sanitize_basic_settings( $input ) {
        $input['location']          = sanitize_text_field( $input['location'] );
        $input['on_mobile']         = isset( $input['on_mobile'] ) ? 'yes' : 'no';
        $input['on_desktop']        = isset( $input['on_desktop'] ) ? 'yes' : 'no';
        $input['auto_popup_status'] = isset( $input['auto_popup_status'] ) ? 'yes' : 'no';
        $input['auto_popup_delay']  = intval( $input['auto_popup_delay'] );
        $input['custom_css']        = wp_kses_post( $input['custom_css'] );
        
        return $input;
    }

    public function sanitize_gdpr_settings( $input ) {
        $input['status']        = isset( $input['status'] ) ? 'yes' : 'no';
        $input['message']       = sanitize_textarea_field( $input['message'] );
        $input['privacy_page']  = intval( $input['privacy_page'] );

        return $input;
    }

}

new TOCHATBE_Admin_Init;